@import "vendors/neat/neat-helpers";

$visual-grid: false;
$grid-columns: 4;  //default for mobile

$medium-size: 768px;
$large-size: 992px;

$medium-cols: 8;
$large-cols: 12;

// Usage: @include media( $medium ){}
$medium: new-breakpoint(min-width $medium-size $medium-cols);
$medium-only: new-breakpoint(min-width $medium-size max-width ($large-size - 1) $medium-cols);
$large: new-breakpoint(min-width $large-size $large-cols);