{% extends 'spirit/_base.html' %}

{% load i18n %}

{% block title %}404{% endblock %}

{% block content %}

    <h1>
        Error 403: {% trans "You do not have sufficient permissions to access this page" %}. :(
    </h1>

{% endblock %}