{% extends "spirit/_base.html" %}

{% load i18n %}

{% block title %}{% trans "Join topic" %}{% endblock %}

{% block content %}

    <h1 class="headline">
        {% blocktrans with topic_title=topic.title %}Do you want to join {{ topic_title }}?{% endblocktrans %}
    </h1>

    <form action="." method="post">
        {% csrf_token %}

        {% include "spirit/_form.html" %}

        <input class="button" type="submit" name="post" value="{% trans "Join" %}" />
    </form>

{% endblock %}