{% extends "spirit/_base.html" %}

{% load i18n %}

{% block title %}{{ category.title }}{% endblock %}

{% block content %}

    {% include "spirit/topic/_top_bar.html" with category=category categories=subcategories %}

    {% include "spirit/topic/_render_page_list.html" with show_subcategory=True %}

{% endblock %}