{% extends "spirit/_base.html" %}

{% load i18n %}

{% block title %}{% trans "Moderate comment" %}{% endblock %}

{% block content %}

    <h1 class="headline">{% trans "Moderate comment" %}</h1>
    
    <form action="." method="post">
        {% csrf_token %}

        <input class="button" type="submit" name="post" value="{% trans "Apply" %}" />
    </form>

{% endblock %}